# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .inspection_service_pb2 import GetConfigForSlowCounterParticipants, GetIntervalsBehindForCounterParticipants, LookupContractDomain, LookupOffsetByIndex, LookupOffsetByTime, LookupReceivedAcsCommitments, LookupSentAcsCommitments, SetConfigForSlowCounterParticipants

__all__ = [
    "InspectionServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class InspectionServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _InspectionServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _InspectionServiceAsyncStub: ...  # type: ignore
    def LookupContractDomain(self, __1: LookupContractDomain.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[LookupContractDomain.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, LookupContractDomain.Response]]: ...
    def LookupOffsetByTime(self, __1: LookupOffsetByTime.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[LookupOffsetByTime.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByTime.Response]]: ...
    def LookupOffsetByIndex(self, __1: LookupOffsetByIndex.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[LookupOffsetByIndex.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByIndex.Response]]: ...
    def LookupSentAcsCommitments(self, __1: LookupSentAcsCommitments.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[LookupSentAcsCommitments.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, LookupSentAcsCommitments.Response]]: ...
    def LookupReceivedAcsCommitments(self, __1: LookupReceivedAcsCommitments.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[LookupReceivedAcsCommitments.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, LookupReceivedAcsCommitments.Response]]: ...
    def SetConfigForSlowCounterParticipants(self, __1: SetConfigForSlowCounterParticipants.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetConfigForSlowCounterParticipants.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SetConfigForSlowCounterParticipants.Response]]: ...
    def GetConfigForSlowCounterParticipants(self, __1: GetConfigForSlowCounterParticipants.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetConfigForSlowCounterParticipants.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, GetConfigForSlowCounterParticipants.Response]]: ...
    def GetIntervalsBehindForCounterParticipants(self, __1: GetIntervalsBehindForCounterParticipants.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetIntervalsBehindForCounterParticipants.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, GetIntervalsBehindForCounterParticipants.Response]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InspectionServiceBlockingStub(InspectionServiceStub):
    def LookupContractDomain(self, __1: LookupContractDomain.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupContractDomain.Response: ...
    def LookupOffsetByTime(self, __1: LookupOffsetByTime.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByTime.Response: ...
    def LookupOffsetByIndex(self, __1: LookupOffsetByIndex.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupOffsetByIndex.Response: ...
    def LookupSentAcsCommitments(self, __1: LookupSentAcsCommitments.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupSentAcsCommitments.Response: ...
    def LookupReceivedAcsCommitments(self, __1: LookupReceivedAcsCommitments.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> LookupReceivedAcsCommitments.Response: ...
    def SetConfigForSlowCounterParticipants(self, __1: SetConfigForSlowCounterParticipants.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetConfigForSlowCounterParticipants.Response: ...
    def GetConfigForSlowCounterParticipants(self, __1: GetConfigForSlowCounterParticipants.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetConfigForSlowCounterParticipants.Response: ...
    def GetIntervalsBehindForCounterParticipants(self, __1: GetIntervalsBehindForCounterParticipants.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetIntervalsBehindForCounterParticipants.Response: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InspectionServiceAsyncStub(InspectionServiceStub):
    def LookupContractDomain(self, __1: LookupContractDomain.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupContractDomain.Response]: ...  # type: ignore
    def LookupOffsetByTime(self, __1: LookupOffsetByTime.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByTime.Response]: ...  # type: ignore
    def LookupOffsetByIndex(self, __1: LookupOffsetByIndex.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupOffsetByIndex.Response]: ...  # type: ignore
    def LookupSentAcsCommitments(self, __1: LookupSentAcsCommitments.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupSentAcsCommitments.Response]: ...  # type: ignore
    def LookupReceivedAcsCommitments(self, __1: LookupReceivedAcsCommitments.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, LookupReceivedAcsCommitments.Response]: ...  # type: ignore
    def SetConfigForSlowCounterParticipants(self, __1: SetConfigForSlowCounterParticipants.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetConfigForSlowCounterParticipants.Response]: ...  # type: ignore
    def GetConfigForSlowCounterParticipants(self, __1: GetConfigForSlowCounterParticipants.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetConfigForSlowCounterParticipants.Response]: ...  # type: ignore
    def GetIntervalsBehindForCounterParticipants(self, __1: GetIntervalsBehindForCounterParticipants.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetIntervalsBehindForCounterParticipants.Response]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import traffic_control_parameters_pb2 as _traffic_control_parameters_pb2
from ....topology.admin.v30 import topology_ext_pb2 as _topology_ext_pb2
from ....v30 import trace_context_pb2 as _trace_context_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendAsyncVersionedRequest(_message.Message):
    __slots__ = ("signed_submission_request",)
    SIGNED_SUBMISSION_REQUEST_FIELD_NUMBER: _ClassVar[int]
    signed_submission_request: bytes
    def __init__(self, signed_submission_request: _Optional[bytes] = ...) -> None: ...

class TrafficControlErrorReason(_message.Message):
    __slots__ = ("error",)
    class Error(_message.Message):
        __slots__ = ("insufficient_traffic", "outdated_traffic_cost")
        INSUFFICIENT_TRAFFIC_FIELD_NUMBER: _ClassVar[int]
        OUTDATED_TRAFFIC_COST_FIELD_NUMBER: _ClassVar[int]
        insufficient_traffic: str
        outdated_traffic_cost: str
        def __init__(self, insufficient_traffic: _Optional[str] = ..., outdated_traffic_cost: _Optional[str] = ...) -> None: ...
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: TrafficControlErrorReason.Error
    def __init__(self, error: _Optional[_Union[TrafficControlErrorReason.Error, _Mapping]] = ...) -> None: ...

class SendAsyncVersionedResponse(_message.Message):
    __slots__ = ("error",)
    class Error(_message.Message):
        __slots__ = ("request_invalid", "request_refused", "overloaded", "sender_unknown", "shutting_down", "unavailable", "unknown_recipients", "internal", "generic", "traffic_control")
        REQUEST_INVALID_FIELD_NUMBER: _ClassVar[int]
        REQUEST_REFUSED_FIELD_NUMBER: _ClassVar[int]
        OVERLOADED_FIELD_NUMBER: _ClassVar[int]
        SENDER_UNKNOWN_FIELD_NUMBER: _ClassVar[int]
        SHUTTING_DOWN_FIELD_NUMBER: _ClassVar[int]
        UNAVAILABLE_FIELD_NUMBER: _ClassVar[int]
        UNKNOWN_RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
        INTERNAL_FIELD_NUMBER: _ClassVar[int]
        GENERIC_FIELD_NUMBER: _ClassVar[int]
        TRAFFIC_CONTROL_FIELD_NUMBER: _ClassVar[int]
        request_invalid: str
        request_refused: str
        overloaded: str
        sender_unknown: str
        shutting_down: str
        unavailable: str
        unknown_recipients: str
        internal: str
        generic: str
        traffic_control: TrafficControlErrorReason
        def __init__(self, request_invalid: _Optional[str] = ..., request_refused: _Optional[str] = ..., overloaded: _Optional[str] = ..., sender_unknown: _Optional[str] = ..., shutting_down: _Optional[str] = ..., unavailable: _Optional[str] = ..., unknown_recipients: _Optional[str] = ..., internal: _Optional[str] = ..., generic: _Optional[str] = ..., traffic_control: _Optional[_Union[TrafficControlErrorReason, _Mapping]] = ...) -> None: ...
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: SendAsyncVersionedResponse.Error
    def __init__(self, error: _Optional[_Union[SendAsyncVersionedResponse.Error, _Mapping]] = ...) -> None: ...

class SubscriptionRequest(_message.Message):
    __slots__ = ("member", "counter")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    member: str
    counter: int
    def __init__(self, member: _Optional[str] = ..., counter: _Optional[int] = ...) -> None: ...

class VersionedSubscriptionResponse(_message.Message):
    __slots__ = ("signed_sequenced_event", "trace_context")
    SIGNED_SEQUENCED_EVENT_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    signed_sequenced_event: bytes
    trace_context: _trace_context_pb2.TraceContext
    def __init__(self, signed_sequenced_event: _Optional[bytes] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ...) -> None: ...

class AcknowledgeRequest(_message.Message):
    __slots__ = ("member", "timestamp")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    member: str
    timestamp: int
    def __init__(self, member: _Optional[str] = ..., timestamp: _Optional[int] = ...) -> None: ...

class AcknowledgeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AcknowledgeSignedRequest(_message.Message):
    __slots__ = ("signed_acknowledge_request",)
    SIGNED_ACKNOWLEDGE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    signed_acknowledge_request: bytes
    def __init__(self, signed_acknowledge_request: _Optional[bytes] = ...) -> None: ...

class AcknowledgeSignedResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DownloadTopologyStateForInitRequest(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: str
    def __init__(self, member: _Optional[str] = ...) -> None: ...

class DownloadTopologyStateForInitResponse(_message.Message):
    __slots__ = ("topology_transactions",)
    TOPOLOGY_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    topology_transactions: _topology_ext_pb2.TopologyTransactions
    def __init__(self, topology_transactions: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ...) -> None: ...

class GetTrafficStateForMemberRequest(_message.Message):
    __slots__ = ("member", "timestamp")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    member: str
    timestamp: int
    def __init__(self, member: _Optional[str] = ..., timestamp: _Optional[int] = ...) -> None: ...

class GetTrafficStateForMemberResponse(_message.Message):
    __slots__ = ("traffic_state",)
    TRAFFIC_STATE_FIELD_NUMBER: _ClassVar[int]
    traffic_state: _traffic_control_parameters_pb2.TrafficState
    def __init__(self, traffic_state: _Optional[_Union[_traffic_control_parameters_pb2.TrafficState, _Mapping]] = ...) -> None: ...

class SequencedEventTrafficState(_message.Message):
    __slots__ = ("extra_traffic_remainder", "extra_traffic_consumed")
    EXTRA_TRAFFIC_REMAINDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_TRAFFIC_CONSUMED_FIELD_NUMBER: _ClassVar[int]
    extra_traffic_remainder: int
    extra_traffic_consumed: int
    def __init__(self, extra_traffic_remainder: _Optional[int] = ..., extra_traffic_consumed: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/experimental_features.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/experimental_features.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/daml/ledger/api/v2/experimental_features.proto\x12\x16\x63om.daml.ledger.api.v2\"\xec\x02\n\x14\x45xperimentalFeatures\x12O\n\x0bstatic_time\x18\x01 \x01(\x0b\x32..com.daml.ledger.api.v2.ExperimentalStaticTimeR\nstaticTime\x12z\n\x1a\x63ommand_inspection_service\x18\x02 \x01(\x0b\x32<.com.daml.ledger.api.v2.ExperimentalCommandInspectionServiceR\x18\x63ommandInspectionService\x12\x86\x01\n\x1einteractive_submission_service\x18\x03 \x01(\x0b\x32@.com.daml.ledger.api.v2.ExperimentalInteractiveSubmissionServiceR\x1cinteractiveSubmissionService\"6\n\x16\x45xperimentalStaticTime\x12\x1c\n\tsupported\x18\x01 \x01(\x08R\tsupported\"D\n$ExperimentalCommandInspectionService\x12\x1c\n\tsupported\x18\x01 \x01(\x08R\tsupported\"H\n(ExperimentalInteractiveSubmissionService\x12\x1c\n\tsupported\x18\x01 \x01(\x08R\tsupportedB\x98\x01\n\x16\x63om.daml.ledger.api.v2B\x1e\x45xperimentalFeaturesOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.experimental_features_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\036ExperimentalFeaturesOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_EXPERIMENTALFEATURES']._serialized_start=79
  _globals['_EXPERIMENTALFEATURES']._serialized_end=443
  _globals['_EXPERIMENTALSTATICTIME']._serialized_start=445
  _globals['_EXPERIMENTALSTATICTIME']._serialized_end=499
  _globals['_EXPERIMENTALCOMMANDINSPECTIONSERVICE']._serialized_start=501
  _globals['_EXPERIMENTALCOMMANDINSPECTIONSERVICE']._serialized_end=569
  _globals['_EXPERIMENTALINTERACTIVESUBMISSIONSERVICE']._serialized_start=571
  _globals['_EXPERIMENTALINTERACTIVESUBMISSIONSERVICE']._serialized_end=643
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .sequencer_connect_service_pb2 import SequencerConnect
from .service_agreement_pb2 import GetServiceAgreementRequest, GetServiceAgreementResponse
from ....protocol.v0.sequencing_pb2 import Handshake

__all__ = [
    "SequencerConnectServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerConnectServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerConnectServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerConnectServiceAsyncStub: ...  # type: ignore
    def Handshake(self, __1: Handshake.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[Handshake.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, Handshake.Response]]: ...
    def GetDomainId(self, __1: SequencerConnect.GetDomainId.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.GetDomainId.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainId.Response]]: ...
    def GetDomainParameters(self, __1: SequencerConnect.GetDomainParameters.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.GetDomainParameters.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainParameters.Response]]: ...
    def VerifyActive(self, __1: SequencerConnect.VerifyActive.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SequencerConnect.VerifyActive.Response, _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.VerifyActive.Response]]: ...
    def GetServiceAgreement(self, __1: GetServiceAgreementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetServiceAgreementResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetServiceAgreementResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerConnectServiceBlockingStub(SequencerConnectServiceStub):
    def Handshake(self, __1: Handshake.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> Handshake.Response: ...
    def GetDomainId(self, __1: SequencerConnect.GetDomainId.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.GetDomainId.Response: ...
    def GetDomainParameters(self, __1: SequencerConnect.GetDomainParameters.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.GetDomainParameters.Response: ...
    def VerifyActive(self, __1: SequencerConnect.VerifyActive.Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SequencerConnect.VerifyActive.Response: ...
    def GetServiceAgreement(self, __1: GetServiceAgreementRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetServiceAgreementResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerConnectServiceAsyncStub(SequencerConnectServiceStub):
    def Handshake(self, __1: Handshake.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, Handshake.Response]: ...  # type: ignore
    def GetDomainId(self, __1: SequencerConnect.GetDomainId.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainId.Response]: ...  # type: ignore
    def GetDomainParameters(self, __1: SequencerConnect.GetDomainParameters.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.GetDomainParameters.Response]: ...  # type: ignore
    def VerifyActive(self, __1: SequencerConnect.VerifyActive.Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SequencerConnect.VerifyActive.Response]: ...  # type: ignore
    def GetServiceAgreement(self, __1: GetServiceAgreementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetServiceAgreementResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from logging import Logger
from typing import Optional, TypedDict

__all__ = ["LoggerArgs"]


class LoggerArgs(TypedDict, total=False):
    logger: Optional[Logger]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/common_stable.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/common_stable.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8com/digitalasset/canton/protocol/v30/common_stable.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\"\xb7\x04\n\x14SerializableContract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x32\n\x15raw_contract_instance\x18\x02 \x01(\x0cR\x13rawContractInstance\x12_\n\x08metadata\x18\x03 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.SerializableContract.MetadataR\x08metadata\x12,\n\x12ledger_create_time\x18\x04 \x01(\x03R\x10ledgerCreateTime\x12M\n\rcontract_salt\x18\x05 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x0c\x63ontractSalt\x1a\xeb\x01\n\x08Metadata\x12<\n\x1anon_maintainer_signatories\x18\x01 \x03(\tR\x18nonMaintainerSignatories\x12<\n\x1anon_signatory_stakeholders\x18\x02 \x03(\tR\x18nonSignatoryStakeholders\x12\x41\n\x03key\x18\x03 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v30.GlobalKeyR\x03key\x12 \n\x0bmaintainers\x18\x04 \x03(\tR\x0bmaintainers\"a\n\tGlobalKey\x12\x1f\n\x0btemplate_id\x18\x01 \x01(\x0cR\ntemplateId\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\"Z\n\x0f\x41ggregationRule\x12)\n\x10\x65ligible_members\x18\x01 \x03(\tR\x0f\x65ligibleMembers\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthresholdBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.common_stable_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_SERIALIZABLECONTRACT']._serialized_start=148
  _globals['_SERIALIZABLECONTRACT']._serialized_end=715
  _globals['_SERIALIZABLECONTRACT_METADATA']._serialized_start=480
  _globals['_SERIALIZABLECONTRACT_METADATA']._serialized_end=715
  _globals['_GLOBALKEY']._serialized_start=717
  _globals['_GLOBALKEY']._serialized_end=814
  _globals['_AGGREGATIONRULE']._serialized_start=816
  _globals['_AGGREGATIONRULE']._serialized_end=906
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .package_service_pb2 import GetDarRequest, GetDarResponse, ListDarContentsRequest, ListDarContentsResponse, ListDarsRequest, ListDarsResponse, ListPackageContentsRequest, ListPackageContentsResponse, ListPackagesRequest, ListPackagesResponse, RemoveDarRequest, RemoveDarResponse, RemovePackageRequest, RemovePackageResponse, UnvetDarRequest, UnvetDarResponse, UploadDarRequest, UploadDarResponse, ValidateDarRequest, ValidateDarResponse, VetDarRequest, VetDarResponse

__all__ = [
    "PackageServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class PackageServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _PackageServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _PackageServiceAsyncStub: ...  # type: ignore
    def ListPackages(self, __1: ListPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListPackagesResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListPackagesResponse]]: ...
    def ListPackageContents(self, __1: ListPackageContentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListPackageContentsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListPackageContentsResponse]]: ...
    def ListDars(self, __1: ListDarsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListDarsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListDarsResponse]]: ...
    def ListDarContents(self, __1: ListDarContentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListDarContentsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListDarContentsResponse]]: ...
    def UploadDar(self, __1: UploadDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[UploadDarResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, UploadDarResponse]]: ...
    def ValidateDar(self, __1: ValidateDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ValidateDarResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ValidateDarResponse]]: ...
    def RemovePackage(self, __1: RemovePackageRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[RemovePackageResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, RemovePackageResponse]]: ...
    def VetDar(self, __1: VetDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[VetDarResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, VetDarResponse]]: ...
    def UnvetDar(self, __1: UnvetDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[UnvetDarResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, UnvetDarResponse]]: ...
    def RemoveDar(self, __1: RemoveDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[RemoveDarResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, RemoveDarResponse]]: ...
    def GetDar(self, __1: GetDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetDarResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetDarResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PackageServiceBlockingStub(PackageServiceStub):
    def ListPackages(self, __1: ListPackagesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPackagesResponse: ...
    def ListPackageContents(self, __1: ListPackageContentsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPackageContentsResponse: ...
    def ListDars(self, __1: ListDarsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDarsResponse: ...
    def ListDarContents(self, __1: ListDarContentsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDarContentsResponse: ...
    def UploadDar(self, __1: UploadDarRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UploadDarResponse: ...
    def ValidateDar(self, __1: ValidateDarRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ValidateDarResponse: ...
    def RemovePackage(self, __1: RemovePackageRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RemovePackageResponse: ...
    def VetDar(self, __1: VetDarRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> VetDarResponse: ...
    def UnvetDar(self, __1: UnvetDarRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UnvetDarResponse: ...
    def RemoveDar(self, __1: RemoveDarRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RemoveDarResponse: ...
    def GetDar(self, __1: GetDarRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetDarResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _PackageServiceAsyncStub(PackageServiceStub):
    def ListPackages(self, __1: ListPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPackagesResponse]: ...  # type: ignore
    def ListPackageContents(self, __1: ListPackageContentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPackageContentsResponse]: ...  # type: ignore
    def ListDars(self, __1: ListDarsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDarsResponse]: ...  # type: ignore
    def ListDarContents(self, __1: ListDarContentsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDarContentsResponse]: ...  # type: ignore
    def UploadDar(self, __1: UploadDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, UploadDarResponse]: ...  # type: ignore
    def ValidateDar(self, __1: ValidateDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ValidateDarResponse]: ...  # type: ignore
    def RemovePackage(self, __1: RemovePackageRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RemovePackageResponse]: ...  # type: ignore
    def VetDar(self, __1: VetDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, VetDarResponse]: ...  # type: ignore
    def UnvetDar(self, __1: UnvetDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, UnvetDarResponse]: ...  # type: ignore
    def RemoveDar(self, __1: RemoveDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RemoveDarResponse]: ...  # type: ignore
    def GetDar(self, __1: GetDarRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetDarResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ...v0 import trace_context_pb2 as _trace_context_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencedEvent(_message.Message):
    __slots__ = ("counter", "timestamp", "domain_id", "message_id", "batch", "deliver_error_reason")
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    DELIVER_ERROR_REASON_FIELD_NUMBER: _ClassVar[int]
    counter: int
    timestamp: _timestamp_pb2.Timestamp
    domain_id: str
    message_id: _wrappers_pb2.StringValue
    batch: CompressedBatch
    deliver_error_reason: DeliverErrorReason
    def __init__(self, counter: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., domain_id: _Optional[str] = ..., message_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., batch: _Optional[_Union[CompressedBatch, _Mapping]] = ..., deliver_error_reason: _Optional[_Union[DeliverErrorReason, _Mapping]] = ...) -> None: ...

class PossiblyIgnoredSequencedEvent(_message.Message):
    __slots__ = ("counter", "timestamp", "trace_context", "is_ignored", "underlying")
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    IS_IGNORED_FIELD_NUMBER: _ClassVar[int]
    UNDERLYING_FIELD_NUMBER: _ClassVar[int]
    counter: int
    timestamp: _timestamp_pb2.Timestamp
    trace_context: _trace_context_pb2.TraceContext
    is_ignored: bool
    underlying: SignedContent
    def __init__(self, counter: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ..., is_ignored: bool = ..., underlying: _Optional[_Union[SignedContent, _Mapping]] = ...) -> None: ...

class RecipientsTree(_message.Message):
    __slots__ = ("recipients", "children")
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    recipients: _containers.RepeatedScalarFieldContainer[str]
    children: _containers.RepeatedCompositeFieldContainer[RecipientsTree]
    def __init__(self, recipients: _Optional[_Iterable[str]] = ..., children: _Optional[_Iterable[_Union[RecipientsTree, _Mapping]]] = ...) -> None: ...

class Recipients(_message.Message):
    __slots__ = ("recipients_tree",)
    RECIPIENTS_TREE_FIELD_NUMBER: _ClassVar[int]
    recipients_tree: _containers.RepeatedCompositeFieldContainer[RecipientsTree]
    def __init__(self, recipients_tree: _Optional[_Iterable[_Union[RecipientsTree, _Mapping]]] = ...) -> None: ...

class Envelope(_message.Message):
    __slots__ = ("content", "recipients")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    content: bytes
    recipients: Recipients
    def __init__(self, content: _Optional[bytes] = ..., recipients: _Optional[_Union[Recipients, _Mapping]] = ...) -> None: ...

class CompressedBatch(_message.Message):
    __slots__ = ("algorithm", "compressed_batch")
    class CompressionAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        None_: _ClassVar[CompressedBatch.CompressionAlgorithm]
        Gzip: _ClassVar[CompressedBatch.CompressionAlgorithm]
    None_: CompressedBatch.CompressionAlgorithm
    Gzip: CompressedBatch.CompressionAlgorithm
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    COMPRESSED_BATCH_FIELD_NUMBER: _ClassVar[int]
    algorithm: CompressedBatch.CompressionAlgorithm
    compressed_batch: bytes
    def __init__(self, algorithm: _Optional[_Union[CompressedBatch.CompressionAlgorithm, str]] = ..., compressed_batch: _Optional[bytes] = ...) -> None: ...

class Batch(_message.Message):
    __slots__ = ("envelopes",)
    ENVELOPES_FIELD_NUMBER: _ClassVar[int]
    envelopes: _containers.RepeatedCompositeFieldContainer[Envelope]
    def __init__(self, envelopes: _Optional[_Iterable[_Union[Envelope, _Mapping]]] = ...) -> None: ...

class SignedContent(_message.Message):
    __slots__ = ("content", "signatures", "timestamp_of_signing_key")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_OF_SIGNING_KEY_FIELD_NUMBER: _ClassVar[int]
    content: _wrappers_pb2.BytesValue
    signatures: _crypto_pb2.Signature
    timestamp_of_signing_key: _timestamp_pb2.Timestamp
    def __init__(self, content: _Optional[_Union[_wrappers_pb2.BytesValue, _Mapping]] = ..., signatures: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., timestamp_of_signing_key: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DeliverErrorReason(_message.Message):
    __slots__ = ("batch_invalid", "batch_refused")
    BATCH_INVALID_FIELD_NUMBER: _ClassVar[int]
    BATCH_REFUSED_FIELD_NUMBER: _ClassVar[int]
    batch_invalid: str
    batch_refused: str
    def __init__(self, batch_invalid: _Optional[str] = ..., batch_refused: _Optional[str] = ...) -> None: ...

class ServiceAgreement(_message.Message):
    __slots__ = ("id", "legal_text")
    ID_FIELD_NUMBER: _ClassVar[int]
    LEGAL_TEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    legal_text: str
    def __init__(self, id: _Optional[str] = ..., legal_text: _Optional[str] = ...) -> None: ...

class StaticDomainParameters(_message.Message):
    __slots__ = ("reconciliation_interval", "max_rate_per_participant", "max_inbound_message_size", "unique_contract_keys", "required_signing_key_schemes", "required_encryption_key_schemes", "required_symmetric_key_schemes", "required_hash_algorithms", "required_crypto_key_formats", "protocol_version")
    RECONCILIATION_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    MAX_RATE_PER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    MAX_INBOUND_MESSAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_CONTRACT_KEYS_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_SIGNING_KEY_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_ENCRYPTION_KEY_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_SYMMETRIC_KEY_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_HASH_ALGORITHMS_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_CRYPTO_KEY_FORMATS_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    reconciliation_interval: _duration_pb2.Duration
    max_rate_per_participant: int
    max_inbound_message_size: int
    unique_contract_keys: bool
    required_signing_key_schemes: _containers.RepeatedScalarFieldContainer[_crypto_pb2.SigningKeyScheme]
    required_encryption_key_schemes: _containers.RepeatedScalarFieldContainer[_crypto_pb2.EncryptionKeyScheme]
    required_symmetric_key_schemes: _containers.RepeatedScalarFieldContainer[_crypto_pb2.SymmetricKeyScheme]
    required_hash_algorithms: _containers.RepeatedScalarFieldContainer[_crypto_pb2.HashAlgorithm]
    required_crypto_key_formats: _containers.RepeatedScalarFieldContainer[_crypto_pb2.CryptoKeyFormat]
    protocol_version: str
    def __init__(self, reconciliation_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_rate_per_participant: _Optional[int] = ..., max_inbound_message_size: _Optional[int] = ..., unique_contract_keys: bool = ..., required_signing_key_schemes: _Optional[_Iterable[_Union[_crypto_pb2.SigningKeyScheme, str]]] = ..., required_encryption_key_schemes: _Optional[_Iterable[_Union[_crypto_pb2.EncryptionKeyScheme, str]]] = ..., required_symmetric_key_schemes: _Optional[_Iterable[_Union[_crypto_pb2.SymmetricKeyScheme, str]]] = ..., required_hash_algorithms: _Optional[_Iterable[_Union[_crypto_pb2.HashAlgorithm, str]]] = ..., required_crypto_key_formats: _Optional[_Iterable[_Union[_crypto_pb2.CryptoKeyFormat, str]]] = ..., protocol_version: _Optional[str] = ...) -> None: ...

class DynamicDomainParameters(_message.Message):
    __slots__ = ("participant_response_timeout", "mediator_reaction_timeout", "transfer_exclusivity_timeout", "topology_change_delay", "ledger_time_record_time_tolerance")
    PARTICIPANT_RESPONSE_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_REACTION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_EXCLUSIVITY_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_CHANGE_DELAY_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIME_RECORD_TIME_TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    participant_response_timeout: _duration_pb2.Duration
    mediator_reaction_timeout: _duration_pb2.Duration
    transfer_exclusivity_timeout: _duration_pb2.Duration
    topology_change_delay: _duration_pb2.Duration
    ledger_time_record_time_tolerance: _duration_pb2.Duration
    def __init__(self, participant_response_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., mediator_reaction_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., transfer_exclusivity_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., topology_change_delay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., ledger_time_record_time_tolerance: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class Handshake(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("client_protocol_versions", "minimum_protocol_version")
        CLIENT_PROTOCOL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
        MINIMUM_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
        client_protocol_versions: _containers.RepeatedScalarFieldContainer[str]
        minimum_protocol_version: _wrappers_pb2.StringValue
        def __init__(self, client_protocol_versions: _Optional[_Iterable[str]] = ..., minimum_protocol_version: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("server_protocol_version", "success", "failure")
        SERVER_PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        server_protocol_version: str
        success: Handshake.Success
        failure: Handshake.Failure
        def __init__(self, server_protocol_version: _Optional[str] = ..., success: _Optional[_Union[Handshake.Success, _Mapping]] = ..., failure: _Optional[_Union[Handshake.Failure, _Mapping]] = ...) -> None: ...
    class Success(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("reason",)
        REASON_FIELD_NUMBER: _ClassVar[int]
        reason: str
        def __init__(self, reason: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class SubmissionRequest(_message.Message):
    __slots__ = ("sender", "message_id", "is_request", "batch", "max_sequencing_time", "timestamp_of_signing_key")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    IS_REQUEST_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    MAX_SEQUENCING_TIME_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_OF_SIGNING_KEY_FIELD_NUMBER: _ClassVar[int]
    sender: str
    message_id: str
    is_request: bool
    batch: CompressedBatch
    max_sequencing_time: _timestamp_pb2.Timestamp
    timestamp_of_signing_key: _timestamp_pb2.Timestamp
    def __init__(self, sender: _Optional[str] = ..., message_id: _Optional[str] = ..., is_request: bool = ..., batch: _Optional[_Union[CompressedBatch, _Mapping]] = ..., max_sequencing_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., timestamp_of_signing_key: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/sequencing.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/sequencing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4com/digitalasset/canton/protocol/v1/sequencing.proto\x12#com.digitalasset.canton.protocol.v1\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc5\x05\n\x16StaticDomainParameters\x12\x30\n\x14unique_contract_keys\x18\x01 \x01(\x08R\x12uniqueContractKeys\x12t\n\x1crequired_signing_key_schemes\x18\x02 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v0.SigningKeySchemeR\x19requiredSigningKeySchemes\x12}\n\x1frequired_encryption_key_schemes\x18\x03 \x03(\x0e\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionKeySchemeR\x1crequiredEncryptionKeySchemes\x12z\n\x1erequired_symmetric_key_schemes\x18\x04 \x03(\x0e\x32\x35.com.digitalasset.canton.crypto.v0.SymmetricKeySchemeR\x1brequiredSymmetricKeySchemes\x12j\n\x18required_hash_algorithms\x18\x05 \x03(\x0e\x32\x30.com.digitalasset.canton.crypto.v0.HashAlgorithmR\x16requiredHashAlgorithms\x12q\n\x1brequired_crypto_key_formats\x18\x06 \x03(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.CryptoKeyFormatR\x18requiredCryptoKeyFormats\x12)\n\x10protocol_version\x18\x07 \x01(\x05R\x0fprotocolVersion\"\xf6\x05\n\x17\x44ynamicDomainParameters\x12[\n\x1cparticipant_response_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1aparticipantResponseTimeout\x12U\n\x19mediator_reaction_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17mediatorReactionTimeout\x12[\n\x1ctransfer_exclusivity_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1atransferExclusivityTimeout\x12M\n\x15topology_change_delay\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x13topologyChangeDelay\x12\x63\n!ledger_time_record_time_tolerance\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1dledgerTimeRecordTimeTolerance\x12R\n\x17reconciliation_interval\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x16reconciliationInterval\x12_\n\x1emediator_deduplication_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1cmediatorDeduplicationTimeout\x12\x37\n\x18max_rate_per_participant\x18\x08 \x01(\rR\x15maxRatePerParticipant\x12(\n\x10max_request_size\x18\t \x01(\rR\x0emaxRequestSizeBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.sequencing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_STATICDOMAINPARAMETERS']._serialized_start=174
  _globals['_STATICDOMAINPARAMETERS']._serialized_end=883
  _globals['_DYNAMICDOMAINPARAMETERS']._serialized_start=886
  _globals['_DYNAMICDOMAINPARAMETERS']._serialized_end=1644
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import topology_manager_read_service_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/topology/admin/v0/topology_manager_read_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TopologyManagerReadServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListAvailableStores = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAvailableStores',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresResult.FromString,
                _registered_method=True)
        self.ListPartyToParticipant = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListPartyToParticipant',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantResult.FromString,
                _registered_method=True)
        self.ListOwnerToKeyMapping = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListOwnerToKeyMapping',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResult.FromString,
                _registered_method=True)
        self.ListNamespaceDelegation = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListNamespaceDelegation',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResult.FromString,
                _registered_method=True)
        self.ListIdentifierDelegation = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListIdentifierDelegation',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationResult.FromString,
                _registered_method=True)
        self.ListSignedLegalIdentityClaim = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListSignedLegalIdentityClaim',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimResult.FromString,
                _registered_method=True)
        self.ListParticipantDomainState = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListParticipantDomainState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateResult.FromString,
                _registered_method=True)
        self.ListMediatorDomainState = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListMediatorDomainState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateResult.FromString,
                _registered_method=True)
        self.ListVettedPackages = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListVettedPackages',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesResult.FromString,
                _registered_method=True)
        self.ListDomainParametersChanges = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListDomainParametersChanges',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesResult.FromString,
                _registered_method=True)
        self.ListAll = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAll',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllResponse.FromString,
                _registered_method=True)


class TopologyManagerReadServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListAvailableStores(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPartyToParticipant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOwnerToKeyMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNamespaceDelegation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIdentifierDelegation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSignedLegalIdentityClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListParticipantDomainState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMediatorDomainState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVettedPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDomainParametersChanges(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAll(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TopologyManagerReadServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListAvailableStores': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAvailableStores,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresResult.SerializeToString,
            ),
            'ListPartyToParticipant': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPartyToParticipant,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantResult.SerializeToString,
            ),
            'ListOwnerToKeyMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOwnerToKeyMapping,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResult.SerializeToString,
            ),
            'ListNamespaceDelegation': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamespaceDelegation,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResult.SerializeToString,
            ),
            'ListIdentifierDelegation': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIdentifierDelegation,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationResult.SerializeToString,
            ),
            'ListSignedLegalIdentityClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSignedLegalIdentityClaim,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimResult.SerializeToString,
            ),
            'ListParticipantDomainState': grpc.unary_unary_rpc_method_handler(
                    servicer.ListParticipantDomainState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateResult.SerializeToString,
            ),
            'ListMediatorDomainState': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMediatorDomainState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateResult.SerializeToString,
            ),
            'ListVettedPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVettedPackages,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesResult.SerializeToString,
            ),
            'ListDomainParametersChanges': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDomainParametersChanges,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesResult.SerializeToString,
            ),
            'ListAll': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAll,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TopologyManagerReadService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListAvailableStores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAvailableStores',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAvailableStoresResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPartyToParticipant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListPartyToParticipant',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListPartyToParticipantResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOwnerToKeyMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListOwnerToKeyMapping',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListNamespaceDelegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListNamespaceDelegation',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListIdentifierDelegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListIdentifierDelegation',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListIdentifierDelegationResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSignedLegalIdentityClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListSignedLegalIdentityClaim',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListSignedLegalIdentityClaimResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListParticipantDomainState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListParticipantDomainState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListParticipantDomainStateResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMediatorDomainState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListMediatorDomainState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListMediatorDomainStateResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListVettedPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListVettedPackages',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListVettedPackagesResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDomainParametersChanges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListDomainParametersChanges',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListDomainParametersChangesResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v0.TopologyManagerReadService/ListAll',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v0_dot_topology__manager__read__service__pb2.ListAllResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .status_service_pb2 import DomainStatusInfo, GetLastErrorTraceRequest, GetLastErrorTraceResponse, GetLastErrorsRequest, GetLastErrorsResponse, HealthDumpChunk, HealthDumpRequest, MediatorNodeStatus, NodeStatus, ParticipantStatusInfo, SequencerAdminStatus, SequencerHealthStatus, SequencerNodeStatus, SetLogLevelRequest, SetLogLevelResponse, TopologyQueueStatus
from .status_service_pb2_grpc import StatusServiceStub

__all__ = [
    "DomainStatusInfo",
    "GetLastErrorTraceRequest",
    "GetLastErrorTraceResponse",
    "GetLastErrorsRequest",
    "GetLastErrorsResponse",
    "HealthDumpChunk",
    "HealthDumpRequest",
    "MediatorNodeStatus",
    "NodeStatus",
    "ParticipantStatusInfo",
    "SequencerAdminStatus",
    "SequencerHealthStatus",
    "SequencerNodeStatus",
    "SetLogLevelRequest",
    "SetLogLevelResponse",
    "StatusServiceStub",
    "TopologyQueueStatus",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ContractMetadata(_message.Message):
    __slots__ = ("created_at", "contract_key_hash", "driver_metadata")
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_KEY_HASH_FIELD_NUMBER: _ClassVar[int]
    DRIVER_METADATA_FIELD_NUMBER: _ClassVar[int]
    created_at: _timestamp_pb2.Timestamp
    contract_key_hash: bytes
    driver_metadata: bytes
    def __init__(self, created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., contract_key_hash: _Optional[bytes] = ..., driver_metadata: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .sequencer_service_pb2 import AcknowledgeSignedRequest, AcknowledgeSignedResponse, DownloadTopologyStateForInitRequest, DownloadTopologyStateForInitResponse, GetTrafficStateForMemberRequest, GetTrafficStateForMemberResponse, SendAsyncVersionedRequest, SendAsyncVersionedResponse, SubscriptionRequest, VersionedSubscriptionResponse

__all__ = [
    "SequencerServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerServiceAsyncStub: ...  # type: ignore
    def SendAsyncVersioned(self, __1: SendAsyncVersionedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SendAsyncVersionedResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncVersionedResponse]]: ...
    def SubscribeVersioned(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[VersionedSubscriptionResponse], _grpc_aio.UnaryStreamCall[_typing.Any, VersionedSubscriptionResponse]]: ...
    def AcknowledgeSigned(self, __1: AcknowledgeSignedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AcknowledgeSignedResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AcknowledgeSignedResponse]]: ...
    def DownloadTopologyStateForInit(self, __1: DownloadTopologyStateForInitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[DownloadTopologyStateForInitResponse], _grpc_aio.UnaryStreamCall[_typing.Any, DownloadTopologyStateForInitResponse]]: ...
    def GetTrafficStateForMember(self, __1: GetTrafficStateForMemberRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetTrafficStateForMemberResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetTrafficStateForMemberResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerServiceBlockingStub(SequencerServiceStub):
    def SendAsyncVersioned(self, __1: SendAsyncVersionedRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SendAsyncVersionedResponse: ...
    def SubscribeVersioned(self, __1: SubscriptionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[VersionedSubscriptionResponse]: ...
    def AcknowledgeSigned(self, __1: AcknowledgeSignedRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AcknowledgeSignedResponse: ...
    def DownloadTopologyStateForInit(self, __1: DownloadTopologyStateForInitRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[DownloadTopologyStateForInitResponse]: ...
    def GetTrafficStateForMember(self, __1: GetTrafficStateForMemberRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetTrafficStateForMemberResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerServiceAsyncStub(SequencerServiceStub):
    def SendAsyncVersioned(self, __1: SendAsyncVersionedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncVersionedResponse]: ...  # type: ignore
    def SubscribeVersioned(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, VersionedSubscriptionResponse]: ...  # type: ignore
    def AcknowledgeSigned(self, __1: AcknowledgeSignedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AcknowledgeSignedResponse]: ...  # type: ignore
    def DownloadTopologyStateForInit(self, __1: DownloadTopologyStateForInitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, DownloadTopologyStateForInitResponse]: ...  # type: ignore
    def GetTrafficStateForMember(self, __1: GetTrafficStateForMemberRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetTrafficStateForMemberResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficControlParameters(_message.Message):
    __slots__ = ("max_base_traffic_amount", "max_base_traffic_accumulation_duration", "read_vs_write_scaling_factor", "set_balance_request_submission_window_size", "enforce_rate_limiting")
    MAX_BASE_TRAFFIC_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    MAX_BASE_TRAFFIC_ACCUMULATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    READ_VS_WRITE_SCALING_FACTOR_FIELD_NUMBER: _ClassVar[int]
    SET_BALANCE_REQUEST_SUBMISSION_WINDOW_SIZE_FIELD_NUMBER: _ClassVar[int]
    ENFORCE_RATE_LIMITING_FIELD_NUMBER: _ClassVar[int]
    max_base_traffic_amount: int
    max_base_traffic_accumulation_duration: _duration_pb2.Duration
    read_vs_write_scaling_factor: int
    set_balance_request_submission_window_size: _duration_pb2.Duration
    enforce_rate_limiting: bool
    def __init__(self, max_base_traffic_amount: _Optional[int] = ..., max_base_traffic_accumulation_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., read_vs_write_scaling_factor: _Optional[int] = ..., set_balance_request_submission_window_size: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., enforce_rate_limiting: bool = ...) -> None: ...

class TrafficReceipt(_message.Message):
    __slots__ = ("consumed_cost", "extra_traffic_consumed", "base_traffic_remainder")
    CONSUMED_COST_FIELD_NUMBER: _ClassVar[int]
    EXTRA_TRAFFIC_CONSUMED_FIELD_NUMBER: _ClassVar[int]
    BASE_TRAFFIC_REMAINDER_FIELD_NUMBER: _ClassVar[int]
    consumed_cost: int
    extra_traffic_consumed: int
    base_traffic_remainder: int
    def __init__(self, consumed_cost: _Optional[int] = ..., extra_traffic_consumed: _Optional[int] = ..., base_traffic_remainder: _Optional[int] = ...) -> None: ...

class TrafficConsumed(_message.Message):
    __slots__ = ("member", "extra_traffic_consumed", "base_traffic_remainder", "last_consumed_cost", "sequencing_timestamp")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_TRAFFIC_CONSUMED_FIELD_NUMBER: _ClassVar[int]
    BASE_TRAFFIC_REMAINDER_FIELD_NUMBER: _ClassVar[int]
    LAST_CONSUMED_COST_FIELD_NUMBER: _ClassVar[int]
    SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    member: str
    extra_traffic_consumed: int
    base_traffic_remainder: int
    last_consumed_cost: int
    sequencing_timestamp: int
    def __init__(self, member: _Optional[str] = ..., extra_traffic_consumed: _Optional[int] = ..., base_traffic_remainder: _Optional[int] = ..., last_consumed_cost: _Optional[int] = ..., sequencing_timestamp: _Optional[int] = ...) -> None: ...

class TrafficPurchased(_message.Message):
    __slots__ = ("member", "serial", "extra_traffic_purchased", "sequencing_timestamp")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    EXTRA_TRAFFIC_PURCHASED_FIELD_NUMBER: _ClassVar[int]
    SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    member: str
    serial: int
    extra_traffic_purchased: int
    sequencing_timestamp: int
    def __init__(self, member: _Optional[str] = ..., serial: _Optional[int] = ..., extra_traffic_purchased: _Optional[int] = ..., sequencing_timestamp: _Optional[int] = ...) -> None: ...

class TrafficState(_message.Message):
    __slots__ = ("extra_traffic_purchased", "extra_traffic_consumed", "base_traffic_remainder", "last_consumed_cost", "timestamp", "serial")
    EXTRA_TRAFFIC_PURCHASED_FIELD_NUMBER: _ClassVar[int]
    EXTRA_TRAFFIC_CONSUMED_FIELD_NUMBER: _ClassVar[int]
    BASE_TRAFFIC_REMAINDER_FIELD_NUMBER: _ClassVar[int]
    LAST_CONSUMED_COST_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    extra_traffic_purchased: int
    extra_traffic_consumed: int
    base_traffic_remainder: int
    last_consumed_cost: int
    timestamp: int
    serial: _wrappers_pb2.UInt32Value
    def __init__(self, extra_traffic_purchased: _Optional[int] = ..., extra_traffic_consumed: _Optional[int] = ..., base_traffic_remainder: _Optional[int] = ..., last_consumed_cost: _Optional[int] = ..., timestamp: _Optional[int] = ..., serial: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...

class SetTrafficPurchasedMessage(_message.Message):
    __slots__ = ("member", "serial", "total_traffic_purchased", "domain_id")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TRAFFIC_PURCHASED_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    member: str
    serial: int
    total_traffic_purchased: int
    domain_id: str
    def __init__(self, member: _Optional[str] = ..., serial: _Optional[int] = ..., total_traffic_purchased: _Optional[int] = ..., domain_id: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .domain_time_service_pb2 import AwaitTimeRequest, AwaitTimeResponse, FetchTimeRequest, FetchTimeResponse

__all__ = [
    "DomainTimeServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class DomainTimeServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _DomainTimeServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _DomainTimeServiceAsyncStub: ...  # type: ignore
    def FetchTime(self, __1: FetchTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[FetchTimeResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, FetchTimeResponse]]: ...
    def AwaitTime(self, __1: AwaitTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AwaitTimeResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AwaitTimeResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainTimeServiceBlockingStub(DomainTimeServiceStub):
    def FetchTime(self, __1: FetchTimeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> FetchTimeResponse: ...
    def AwaitTime(self, __1: AwaitTimeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AwaitTimeResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainTimeServiceAsyncStub(DomainTimeServiceStub):
    def FetchTime(self, __1: FetchTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, FetchTimeResponse]: ...  # type: ignore
    def AwaitTime(self, __1: AwaitTimeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AwaitTimeResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/reassignment_command.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/reassignment_command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1com/daml/ledger/api/v2/reassignment_command.proto\x12\x16\x63om.daml.ledger.api.v2\"\xf0\x02\n\x13ReassignmentCommand\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12%\n\x0e\x61pplication_id\x18\x02 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12\x1c\n\tsubmitter\x18\x04 \x01(\tR\tsubmitter\x12T\n\x10unassign_command\x18\x05 \x01(\x0b\x32\'.com.daml.ledger.api.v2.UnassignCommandH\x00R\x0funassignCommand\x12N\n\x0e\x61ssign_command\x18\x06 \x01(\x0b\x32%.com.daml.ledger.api.v2.AssignCommandH\x00R\rassignCommand\x12#\n\rsubmission_id\x18\x07 \x01(\tR\x0csubmissionIdB\t\n\x07\x63ommand\"b\n\x0fUnassignCommand\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x16\n\x06source\x18\x02 \x01(\tR\x06source\x12\x16\n\x06target\x18\x03 \x01(\tR\x06target\"`\n\rAssignCommand\x12\x1f\n\x0bunassign_id\x18\x01 \x01(\tR\nunassignId\x12\x16\n\x06source\x18\x02 \x01(\tR\x06source\x12\x16\n\x06target\x18\x03 \x01(\tR\x06targetB\x97\x01\n\x16\x63om.daml.ledger.api.v2B\x1dReassignmentCommandOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.reassignment_command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\035ReassignmentCommandOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_REASSIGNMENTCOMMAND']._serialized_start=78
  _globals['_REASSIGNMENTCOMMAND']._serialized_end=446
  _globals['_UNASSIGNCOMMAND']._serialized_start=448
  _globals['_UNASSIGNCOMMAND']._serialized_end=546
  _globals['_ASSIGNCOMMAND']._serialized_start=548
  _globals['_ASSIGNCOMMAND']._serialized_end=644
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import topology_pb2 as _topology_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ForceFlag(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    FORCE_FLAG_UNSPECIFIED: _ClassVar[ForceFlag]
    FORCE_FLAG_ALIEN_MEMBER: _ClassVar[ForceFlag]
    FORCE_FLAG_LEDGER_TIME_RECORD_TIME_TOLERANCE_INCREASE: _ClassVar[ForceFlag]
FORCE_FLAG_UNSPECIFIED: ForceFlag
FORCE_FLAG_ALIEN_MEMBER: ForceFlag
FORCE_FLAG_LEDGER_TIME_RECORD_TIME_TOLERANCE_INCREASE: ForceFlag

class GenerateTransactionsRequest(_message.Message):
    __slots__ = ("proposals",)
    class Proposal(_message.Message):
        __slots__ = ("operation", "serial", "mapping", "store")
        OPERATION_FIELD_NUMBER: _ClassVar[int]
        SERIAL_FIELD_NUMBER: _ClassVar[int]
        MAPPING_FIELD_NUMBER: _ClassVar[int]
        STORE_FIELD_NUMBER: _ClassVar[int]
        operation: _topology_pb2.Enums.TopologyChangeOp
        serial: int
        mapping: _topology_pb2.TopologyMapping
        store: str
        def __init__(self, operation: _Optional[_Union[_topology_pb2.Enums.TopologyChangeOp, str]] = ..., serial: _Optional[int] = ..., mapping: _Optional[_Union[_topology_pb2.TopologyMapping, _Mapping]] = ..., store: _Optional[str] = ...) -> None: ...
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    proposals: _containers.RepeatedCompositeFieldContainer[GenerateTransactionsRequest.Proposal]
    def __init__(self, proposals: _Optional[_Iterable[_Union[GenerateTransactionsRequest.Proposal, _Mapping]]] = ...) -> None: ...

class GenerateTransactionsResponse(_message.Message):
    __slots__ = ("generated_transactions",)
    class GeneratedTransaction(_message.Message):
        __slots__ = ("serialized_transaction", "transaction_hash")
        SERIALIZED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
        TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
        serialized_transaction: bytes
        transaction_hash: bytes
        def __init__(self, serialized_transaction: _Optional[bytes] = ..., transaction_hash: _Optional[bytes] = ...) -> None: ...
    GENERATED_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    generated_transactions: _containers.RepeatedCompositeFieldContainer[GenerateTransactionsResponse.GeneratedTransaction]
    def __init__(self, generated_transactions: _Optional[_Iterable[_Union[GenerateTransactionsResponse.GeneratedTransaction, _Mapping]]] = ...) -> None: ...

class AuthorizeRequest(_message.Message):
    __slots__ = ("proposal", "transaction_hash", "must_fully_authorize", "force_changes", "signed_by", "store")
    class Proposal(_message.Message):
        __slots__ = ("change", "serial", "mapping")
        CHANGE_FIELD_NUMBER: _ClassVar[int]
        SERIAL_FIELD_NUMBER: _ClassVar[int]
        MAPPING_FIELD_NUMBER: _ClassVar[int]
        change: _topology_pb2.Enums.TopologyChangeOp
        serial: int
        mapping: _topology_pb2.TopologyMapping
        def __init__(self, change: _Optional[_Union[_topology_pb2.Enums.TopologyChangeOp, str]] = ..., serial: _Optional[int] = ..., mapping: _Optional[_Union[_topology_pb2.TopologyMapping, _Mapping]] = ...) -> None: ...
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    MUST_FULLY_AUTHORIZE_FIELD_NUMBER: _ClassVar[int]
    FORCE_CHANGES_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FIELD_NUMBER: _ClassVar[int]
    STORE_FIELD_NUMBER: _ClassVar[int]
    proposal: AuthorizeRequest.Proposal
    transaction_hash: str
    must_fully_authorize: bool
    force_changes: _containers.RepeatedScalarFieldContainer[ForceFlag]
    signed_by: _containers.RepeatedScalarFieldContainer[str]
    store: str
    def __init__(self, proposal: _Optional[_Union[AuthorizeRequest.Proposal, _Mapping]] = ..., transaction_hash: _Optional[str] = ..., must_fully_authorize: bool = ..., force_changes: _Optional[_Iterable[_Union[ForceFlag, str]]] = ..., signed_by: _Optional[_Iterable[str]] = ..., store: _Optional[str] = ...) -> None: ...

class AuthorizeResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _topology_pb2.SignedTopologyTransaction
    def __init__(self, transaction: _Optional[_Union[_topology_pb2.SignedTopologyTransaction, _Mapping]] = ...) -> None: ...

class AddTransactionsRequest(_message.Message):
    __slots__ = ("transactions", "force_changes", "store")
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    FORCE_CHANGES_FIELD_NUMBER: _ClassVar[int]
    STORE_FIELD_NUMBER: _ClassVar[int]
    transactions: _containers.RepeatedCompositeFieldContainer[_topology_pb2.SignedTopologyTransaction]
    force_changes: _containers.RepeatedScalarFieldContainer[ForceFlag]
    store: str
    def __init__(self, transactions: _Optional[_Iterable[_Union[_topology_pb2.SignedTopologyTransaction, _Mapping]]] = ..., force_changes: _Optional[_Iterable[_Union[ForceFlag, str]]] = ..., store: _Optional[str] = ...) -> None: ...

class AddTransactionsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ImportTopologySnapshotRequest(_message.Message):
    __slots__ = ("topology_snapshot", "store")
    TOPOLOGY_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    STORE_FIELD_NUMBER: _ClassVar[int]
    topology_snapshot: bytes
    store: str
    def __init__(self, topology_snapshot: _Optional[bytes] = ..., store: _Optional[str] = ...) -> None: ...

class ImportTopologySnapshotResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SignTransactionsRequest(_message.Message):
    __slots__ = ("transactions", "signed_by")
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FIELD_NUMBER: _ClassVar[int]
    transactions: _containers.RepeatedCompositeFieldContainer[_topology_pb2.SignedTopologyTransaction]
    signed_by: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, transactions: _Optional[_Iterable[_Union[_topology_pb2.SignedTopologyTransaction, _Mapping]]] = ..., signed_by: _Optional[_Iterable[str]] = ...) -> None: ...

class SignTransactionsResponse(_message.Message):
    __slots__ = ("transactions",)
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    transactions: _containers.RepeatedCompositeFieldContainer[_topology_pb2.SignedTopologyTransaction]
    def __init__(self, transactions: _Optional[_Iterable[_Union[_topology_pb2.SignedTopologyTransaction, _Mapping]]] = ...) -> None: ...
